@@ -28,7 +28,7 @@ from .validators import ModelExistingValidator, ModelLoadedValidator
 from .validators import InputValidator, ArgumentValidator
 from . import exceptions
 
-from transformers import BertTokenizer, BertForSequenceClassification, BertConfig, RobertaForSequenceClassification, RobertaTokenizer, AutoTokenizer
+from transformers import BertTokenizer, BertForSequenceClassification, BertConfig, RobertaForSequenceClassification, RobertaTokenizer, AutoTokenizer, AutoConfig
 from transformers import AdamW, get_linear_schedule_with_warmup
 
 from torch.utils.data import DataLoader, TensorDataset
@@ -320,7 +320,9 @@ class BertTagger:
                 except Exception as e:
                     if logger: logger.info(f"Failed loading RobertaTokenizer, trying to use AutoTokenizer...")
                     model_kwargs.update({"use_fast": False})
+                    config = AutoConfig.from_pretrained(bert_model)
                     tokenizer = AutoTokenizer.from_pretrained(bert_model, **model_kwargs)
+                    config.save_pretrained(tokenizer_dir)
 
             tokenizer.save_pretrained(tokenizer_dir)
             if logger: logger.info(f"Download finished! Pretrained tokenizer saved into {tokenizer_dir}.")
@@ -539,20 +541,26 @@ class BertTagger:
             model_to_load = model_dir
             model_downloaded = True
 
+
         model_kwargs = {}
         if self.cache_dir:
             model_kwargs.update({"cache_dir": self.cache_dir})
 
         if not BertTagger.is_roberta_model(model_to_load):
             self._print("Using regular BERT tokenizer...")
+            if self.logger: self.logger.info(f"Using regular BERT tokenizer...")
             tokenizer = BertTokenizer.from_pretrained(model_to_load, **model_kwargs)
         else:
             try:
                 self._print("Using RobertaTokenizer...")
+                if self.logger: self.logger.info(f"Using RobertaTokenizer...")
+
                 tokenizer = RobertaTokenizer.from_pretrained(model_to_load, **model_kwargs)
             except Exception as e:
                 self._print("Failed loading RobertaTokenizer, trying to use AutoTokenizer...")
+                if self.logger: self.logger.info(f"Failed loading RobertaTokenizer, trying to use AutoTokenizer...")
                 model_kwargs.update({"use_fast": False})
+
                 tokenizer = AutoTokenizer.from_pretrained(model_to_load, **model_kwargs)
 
 
